==> openjdk-19_19~23ea.orig.tar.xz: openjdk-19-19~23ea/test/hotspot/jtreg/compiler/lib/ir_framework/shared/Comparison.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.shared;

import java.util.function.BiPredicate;
import java.util.function.Function;

/**
 * Comparison result of parsing a constraint with {@link ComparisonConstraintParser#parse(String, Function, String)}.
 */
public class Comparison<T extends Comparable<T>> {
    private final T givenValue; // Right hand side
    private final BiPredicate<T, T> comparisonPredicate;
    private final String comparator;

    public Comparison(T givenValue, String comparator, BiPredicate<T, T> comparisonPredicate) {
        this.givenValue = givenValue;
        this.comparator = comparator;
        this.comparisonPredicate = comparisonPredicate;
    }

    public T getGivenValue() {
        return givenValue;
    }

    public String getComparator() {
        return comparator;
    }

    /**
     * Comparison: foundValue OP givenValue
     */
    public boolean compare(T foundValue) {
        return comparisonPredicate.test(foundValue, givenValue);
    }
}

==> openjdk-21_21~7ea.orig.tar.xz: openjdk-21-21~7ea/test/hotspot/jtreg/compiler/lib/ir_framework/shared/Comparison.java <==
/*
 * Copyright (c) 2022, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

package compiler.lib.ir_framework.shared;

import compiler.lib.ir_framework.IR;

import java.util.function.BiPredicate;

/**
 * Comparison result of parsing a {@link IR#counts} constraint with {@link ComparisonConstraintParser}
 *
 * @see ComparisonConstraintParser
 * @see IR#counts
 */
public class Comparison<T extends Comparable<T>> {
    private final T givenValue; // Right hand side
    private final BiPredicate<T, T> comparisonPredicate;
    private final String comparator;

    public Comparison(T givenValue, String comparator, BiPredicate<T, T> comparisonPredicate) {
        this.givenValue = givenValue;
        this.comparator = comparator;
        this.comparisonPredicate = comparisonPredicate;
    }

    public T getGivenValue() {
        return givenValue;
    }

    public String getComparator() {
        return comparator;
    }

    /**
     * Comparison: foundValue OP givenValue
     */
    public boolean compare(T foundValue) {
        return comparisonPredicate.test(foundValue, givenValue);
    }
}
